@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.  You may
@@ -214,8 +214,18 @@ static inline MagickRealType GetPixelInfoChannel(
     case RedPixelChannel: return(pixel_info->red);
     case GreenPixelChannel: return(pixel_info->green);
     case BluePixelChannel: return(pixel_info->blue);
-    case BlackPixelChannel: return(pixel_info->black);
-    case AlphaPixelChannel: return(pixel_info->alpha);
+    case BlackPixelChannel:
+    {
+      if (pixel_info->colorspace != CMYKColorspace)
+        return(0.0);
+      return(pixel_info->black);
+    }
+    case AlphaPixelChannel:
+    {
+      if (pixel_info->alpha_trait == UndefinedPixelTrait)
+        return(OpaqueAlpha);
+      return(pixel_info->alpha);
+    }
     case IndexPixelChannel: return(pixel_info->index);
     default: return((MagickRealType) 0.0);
   }
@@ -411,14 +421,11 @@ static inline void GetPixelInfoPixel(const Image *magick_restrict image,
             pixel_info->black=(MagickRealType)
               pixel[image->channel_map[BlackPixelChannel].offset];
           if (image->channel_map[AlphaPixelChannel].traits != UndefinedPixelTrait)
-            {
-              pixel_info->alpha=(MagickRealType)
-                pixel[image->channel_map[AlphaPixelChannel].offset];
-              pixel_info->alpha_trait=BlendPixelTrait;
-            }
+            pixel_info->alpha=(MagickRealType)
+              pixel[image->channel_map[AlphaPixelChannel].offset];
           if (image->channel_map[IndexPixelChannel].traits != UndefinedPixelTrait)
             pixel_info->index=(MagickRealType)
-          pixel[image->channel_map[IndexPixelChannel].offset];
+              pixel[image->channel_map[IndexPixelChannel].offset];
         }
     }
 }
